Skip to main content

Takoyaki GitHub release (latest by date) GitHub Workflow Status Pypi version

Takoyaki is a simple tool to create random/burner instant mails and generate registration credentials. It's simply cli version of m.kuku.lu service and a cli frontend to sute-mail-python module.

Installation & Usage

You can simply install it from pypi pip install takoyaki You can also download the prebuilt binaries from releases or run the script directly from tako symlink after installing dependencies with pip3 install -r requirements.txt.

Usage

Takoyaki is an interactive burner mail creator and controller.
Usage:
  takoyaki [COMMAND] [ARGS...]
  takoyaki -h | --help

Commands:
  create [-h]               Create new random mail address
  read   [-hal]             Read mails from specified address
  wait   [-ha]              Wait for new mails on specified address
  del    [-ha]              Delete specified mail address
  list   [-h]               List current mail addresses
  gen    [-hwpusac]         Generate registration details
  get    [name]             Get credentials of account you already saved

Options:
  -h, --help                Show extended information about the subcommand
  -a, --address ADDRESS     Specify the mail address
  -l, --last                Select latest mail
  -p, --password            Generate password
  -u, --uname               Generate username
  -w, --Wait                Start listening new mails after generate
  -s, --save NAME           Save generated info to accounts file
  -c, --custom NAME VALUE   Add custom fields when saving

Examples:

# Create a new random instant mail address
$ tako create
created: penanegya@mirai.re

# List existing addresses
$ tako list
1  misukedo@via.tokyo.jp
2  kyakidokya@eay.jp
3  penanegya@mirai.re

# Let's read mails on the kyakidokya@eay.jp
tako read -a kyaki
> No mails.
# or you can also specify index of address
tako read -a 2
> No mails.

# Let's create a burner account for a gaming site,
# generate a random password and a username,
# save the credentials we generated to .accs file and wait for the verification mail.
tako gen -a1 -puws "some name"
or the long version;
tako gen --address 1 --uname --password --wait --save="some name"
=== Some Name Account ===
Mail: misukedo@via.tokyo.jp
Nick: jturlj74 
Pass: v0OEksf7.maiVdJ 

Waiting new mails for misukedo@via.tokyo.jp
Press Ctrl+C to Abort.

Metadata

Release files for takoyaki 2

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for takoyaki 2
File Size Uploaded
takoyaki-2.tar.gz 12.5 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for takoyaki 2
File Interpreter ABI Platform
takoyaki-2-py3-none-any.whl Python 3 none any Details

Total release size: 26.9 kB

Release files / takoyaki-2.tar.gz

Download URL takoyaki-2.tar.gz
Size 12.5 kB
Tags Source
SHA-256 checksum
How to use checksums
e8fa5456cae16f6c4470fab960a00db4741ef4072463cfb049b9176e7eea5cf7
BLAKE2b-256 checksum
How to use checksums
4159c19941ac97c4538d6cfae20716e766e1b1f278206917589148d1772e57e7
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/1.1.13 CPython/3.9.2 Linux/5.10.0-12-amd64

Release files / takoyaki-2-py3-none-any.whl

Download URL takoyaki-2-py3-none-any.whl
Size 14.4 kB
Tags Python 3
SHA-256 checksum
How to use checksums
aa777ed6df5a4e15a6868252c7474a58c490de10fbb8e08757dc1c4bcb03ad61
BLAKE2b-256 checksum
How to use checksums
04842f9047bf79b66a0e86720f3fe55e54baaaa8ee3ba51dd24b906d6855d4d6
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/1.1.13 CPython/3.9.2 Linux/5.10.0-12-amd64

Release history Release notifications | RSS feed

This release

2 This release

2 release files

1.1.1

2 release files

1.1.0

2 release files

1.0.1

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page